@@ -2,6 +2,7 @@ import csv
 import hashlib
 import io
 import json
+import os
 import re
 import string
 import tarfile
@@ -41,10 +42,18 @@ class Provider(BaseProvider):
     def binary(self, length: int = (1 * 1024 * 1024)) -> bytes:
         """Generate a random binary blob of ``length`` bytes.
 
+        If this faker instance has been seeded, performance will be signficiantly reduced, to conform
+        to the seeding.
+
         :sample: length=64
         """
-        blob = [self.generator.random.randrange(256) for _ in range(length)]
-        return bytes(blob)
+        # If the generator has already been seeded, urandom can't be used
+        if self.generator._is_seeded:
+            blob = [self.generator.random.randrange(256) for _ in range(length)]
+            return bytes(blob)
+
+        # Generator is unseeded anyway, just use urandom
+        return os.urandom(length)
 
     def md5(self, raw_output: bool = False) -> Union[bytes, str]:
         """Generate a random MD5 hash.
@@ -61,9 +70,9 @@ class Provider(BaseProvider):
         return res.hexdigest()
 
     def sha1(self, raw_output: bool = False) -> Union[bytes, str]:
-        """Generate a random SHA1 hash.
+        """Generate a random SHA-1 hash.
 
-        If ``raw_output`` is ``False`` (default), a hexadecimal string representation of the SHA1 hash
+        If ``raw_output`` is ``False`` (default), a hexadecimal string representation of the SHA-1 hash
         will be returned. If ``True``, a ``bytes`` object representation will be returned instead.
 
         :sample: raw_output=False
@@ -75,9 +84,9 @@ class Provider(BaseProvider):
         return res.hexdigest()
 
     def sha256(self, raw_output: bool = False) -> Union[bytes, str]:
-        """Generate a random SHA256 hash.
+        """Generate a random SHA-256 hash.
 
-        If ``raw_output`` is ``False`` (default), a hexadecimal string representation of the SHA56 hash
+        If ``raw_output`` is ``False`` (default), a hexadecimal string representation of the SHA-256 hash
         will be returned. If ``True``, a ``bytes`` object representation will be returned instead.
 
         :sample: raw_output=False
@@ -479,7 +488,7 @@ class Provider(BaseProvider):
             delimiter="|",
         )
 
-    def json(self, data_columns: List = None, num_rows: int = 10, indent: int = None) -> str:
+    def json(self, data_columns: Optional[List] = None, num_rows: int = 10, indent: Optional[int] = None) -> str:
         """
         Generate random JSON structure values.
 
@@ -581,7 +590,7 @@ class Provider(BaseProvider):
         data = [create_json_structure(data_columns) for _ in range(num_rows)]
         return json.dumps(data, indent=indent)
 
-    def fixed_width(self, data_columns: list = None, num_rows: int = 10, align: str = "left") -> str:
+    def fixed_width(self, data_columns: Optional[list] = None, num_rows: int = 10, align: str = "left") -> str:
         """
         Generate random fixed width values.
 
